/**
 * Deserialize data received from WebSocket or EventStream.
 * Attempts to parse as JSON if the data looks like JSON, otherwise returns as-is.
 */
export declare const deserializeData: <T>(data: string) => T;
//# sourceMappingURL=serialization.d.ts.map