/**
 * Simple JSON-based equality check for memoization.
 * Compares stringified JSON to avoid deep equality overhead.
 */
export declare function jsonEqual<T>(a: T, b: T): boolean;
//# sourceMappingURL=memo.d.ts.map