export interface UTMParams {
    utm_source?: string;
    utm_medium?: string;
    utm_campaign?: string;
    utm_term?: string;
    utm_content?: string;
}
/**
 * Extract UTM parameters from the current URL
 */
export declare function getUTMParams(): UTMParams;
//# sourceMappingURL=utm.d.ts.map